Scriptname NW_AspectBonusesScript extends activemagiceffect  
{ Aspect Bonuses Script. }

Quest Property DruidTrackingQuest Auto
Quest Property ConfigMenu Auto
Race Property AspectRace Auto
String Property PrimaryStat Auto
float Property LevelMult Auto
float Property AlterationMult Auto
float Property BonusMult Auto
float Property HealthDiminisher Auto
float Property StaminaDiminisher Auto
float Property DamageResistDiminisher Auto
float Property MagicResistDiminisher Auto
float Property FrostResistDiminisher Auto
float Property FireResistDiminisher Auto
float Property SpeedDiminisher Auto
float Property UnarmedDamageDiminisher Auto
Faction Property AspectFaction Auto

float PercentHealth
NW_NaturesWrathHousekeepingScript HousekeepingScript
NW_SkiConfigMenu ConfigMenuScript

; Player Stats
Actor Player
int PlayerLevel
float PlayerAlteration

; Calculated Bonuses
float StatMultiplier
float StatOffset
float DamageResist
float MagicResist
float FrostResist
float FireResist
float SpeedMult
float Stamina
float Health
float UnarmedDamage

; Normalization
float PercentStat
float BaseStat
float StatAmount
float ReductionAmount

Function RecalculateStat(String statName)
	PercentStat = 1 - Game.GetPlayer().GetAVPercentage(statName)

	If(PercentStat > 1 || PercentStat < 0)
		PercentStat = 0.8
	EndIf

	BaseStat = Game.GetPlayer().GetBaseActorValue(statName)
	ReductionAmount = BaseStat * PercentStat

	If(statName == "Health")
		StatAmount = Health
	Else
		StatAmount = Stamina
	EndIf

	Game.GetPlayer().RestoreAV(statName, 99999)
	Player.ModActorValue(statName, -(StatAmount))
	Game.GetPlayer().DamageActorValue(statName, ReductionAmount)
EndFunction

Function CalculateBonuses(float BonusStat)
	StatOffset = ((PlayerLevel * LevelMult) + (PlayerAlteration * AlterationMult)) + (BonusStat * BonusMult)
	Health = (StatOffset * StatMultiplier) * HealthDiminisher
	Stamina = (StatOffset * StatMultiplier) * StaminaDiminisher
	DamageResist = ((StatOffset * StatMultiplier) * DamageResistDiminisher)
	MagicResist = StatOffset * MagicResistDiminisher
	FrostResist = StatOffset * FrostResistDiminisher
	FireResist = StatOffset * FireResistDiminisher
	SpeedMult = StatOffset * SpeedDiminisher
	UnarmedDamage = (StatOffset * StatMultiplier) * UnarmedDamageDiminisher

	If(SpeedMult > 100)
		SpeedMult = 100
	EndIf
EndFunction

Function ApplyBonuses(float BonusStat)
	CalculateBonuses(BonusStat)
	Player.ModActorValue("DamageResist", DamageResist)
	Player.ModActorValue("MagicResist", MagicResist)
	Player.ModActorValue("FrostResist", FrostResist)
	Player.ModActorValue("FireResist", FireResist)
	Player.ModActorValue("SpeedMult", SpeedMult)
	Player.ModActorValue("Health", Health)
	Player.ModActorValue("Stamina", Stamina)
	Player.ModActorValue("UnarmedDamage", UnarmedDamage)
EndFunction

Function RemoveBonuses()
	Player.ModActorValue("DamageResist", -(DamageResist))
	Player.ModActorValue("MagicResist", -(MagicResist))
	Player.ModActorValue("FrostResist", -(FrostResist))
	Player.ModActorValue("FireResist", -(FireResist))
	Player.ModActorValue("SpeedMult", -(SpeedMult))
	RecalculateStat("Health")
	RecalculateStat("Stamina")
	Player.ModActorValue("UnarmedDamage", -(UnarmedDamage))
EndFunction

Event OnInit()
	Player = Game.GetPlayer()
	PlayerLevel = Player.GetLevel()
	PlayerAlteration = Player.GetActorValue("Alteration")

	HousekeepingScript = DruidTrackingQuest as NW_NaturesWrathHousekeepingScript

	If(HousekeepingScript.HasSKSE())
		ConfigMenuScript = ConfigMenu as NW_SkiConfigMenu
		StatMultiplier = ConfigMenuScript.NW_StatMultiplier
	Else
		StatMultiplier = 1.0
	EndIf
EndEvent

Event OnEffectStart(Actor akTarget, Actor akCaster)
	float MainStat = Game.GetPlayer().GetBaseActorValue(PrimaryStat)
	ApplyBonuses(MainStat)
EndEvent

Event OnEffectFinish(Actor akTarget, Actor akCaster)
	RemoveBonuses()
EndEvent