ScriptName NW_SkiConfigMenu Extends SKI_ConfigBase

int Function GetVersion()
	Return 1 ; Last version
EndFunction

;------------  Private Variables
; OIDs (T:Text B:Toggle S:Slider M:Menu, C:Color, K:Key)
int NW_IntroAnimEnabled_OID_B
int NW_OutroAnimEnabled_OID_B
int NW_AmbientEffectEnabled_OID_B
int NW_CloakEffectEnabled_OID_B
int NW_StatMultiplier_OID_S
int NW_TreeSpiritMultiplier_OID_S

; States
bool Property NW_IntroAnimEnabled Auto
bool Property NW_OutroAnimEnabled Auto
bool Property NW_AmbientEffectEnabled Auto
bool Property NW_CloakEffectEnabled Auto
float Property NW_StatMultiplier Auto
float Property NW_TreeSpiritMultiplier Auto

; GlobalVariable States

Event OnConfigInit()
	; Creating pages
	Pages = new String[1]
	Pages[0] = "General"
EndEvent

Event OnVersionUpdate(int version)

EndEvent

Event OnPageReset(string page)
	{Called when a new page is selected, including the initial empty page}
	If(page == "General")
		UnloadCustomContent()
		SetCursorFillMode(TOP_TO_BOTTOM)
		AddHeaderOption("Visual Effects")
		NW_IntroAnimEnabled_OID_B = AddToggleOption("Intro Animation", NW_IntroAnimEnabled)
		NW_OutroAnimEnabled_OID_B = AddToggleOption("Outro Animation", NW_OutroAnimEnabled)
		NW_AmbientEffectEnabled_OID_B = AddToggleOption("Ambient Effect", NW_AmbientEffectEnabled)
		NW_CloakEffectEnabled_OID_B = AddToggleOption("Cloak Visual Effect", NW_CloakEffectEnabled)
		AddHeaderOption("Handicap Setting")
		NW_StatMultiplier_OID_S = AddSliderOption("Multiply Stats by", NW_StatMultiplier, "{2}")
		NW_TreeSpiritMultiplier_OID_S = AddSliderOption("Max Tree Spirits", NW_TreeSpiritMultiplier, "{0}")
	Else
		LoadCustomContent("wrath of nature/pod-cover.dds", 65, 160)
	EndIf
EndEvent

Event OnOptionHighlight(int option)
	{Called when highlighting an option}

	If (option == NW_IntroAnimEnabled_OID_B )	
		SetInfoText("Allows the aspect to perform an animation when entering a transformation.")
		Return
	EndIf
	If (option == NW_OutroAnimEnabled_OID_B )	
		SetInfoText("Allows the aspect to perform an animation when exiting a transformation.")
		Return
	EndIf
	If (option == NW_AmbientEffectEnabled_OID_B )	
		SetInfoText("Ambient effect is applied around the aspect when this is enabled.")
		Return
	EndIf
	If (option == NW_CloakEffectEnabled_OID_B )	
		SetInfoText("Shows a cloak visual effect on the aspect when enabled.")
		Return
	EndIf
	If (option == NW_StatMultiplier_OID_S )	
		SetInfoText("Modify aspect bonuses by chosen multiplier.")
		Return
	EndIf
	If (option == NW_TreeSpiritMultiplier_OID_S )	
		SetInfoText("Number of summoned Tree Spirits with 100 and above skill on Alteration.")
		Return
	EndIf
EndEvent

Event OnOptionSelect(int option)
	{Called when a non-interactive option has been selected}
	
	If ( option == NW_IntroAnimEnabled_OID_B )
		NW_IntroAnimEnabled = !NW_IntroAnimEnabled
		SetToggleOptionValue(NW_IntroAnimEnabled_OID_B, NW_IntroAnimEnabled)
		Return
	EndIf

	If ( option == NW_OutroAnimEnabled_OID_B )
		NW_OutroAnimEnabled = !NW_OutroAnimEnabled
		SetToggleOptionValue(NW_OutroAnimEnabled_OID_B, NW_OutroAnimEnabled)
		Return
	EndIf

	If ( option == NW_AmbientEffectEnabled_OID_B )
		NW_AmbientEffectEnabled = !NW_AmbientEffectEnabled
		SetToggleOptionValue(NW_AmbientEffectEnabled_OID_B, NW_AmbientEffectEnabled)
		Return
	EndIf

	If ( option == NW_CloakEffectEnabled_OID_B )
		NW_CloakEffectEnabled = !NW_CloakEffectEnabled
		SetToggleOptionValue(NW_CloakEffectEnabled_OID_B, NW_CloakEffectEnabled)
		Return
	EndIf
EndEvent

Event OnOptionSliderOpen(int option)
	If ( option == NW_StatMultiplier_OID_S )
		SetSliderDialogStartValue(NW_StatMultiplier)
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(1.0, 3.0)
		SetSliderDialogInterval(0.25)
		Return
	EndIf
	If ( option == NW_TreeSpiritMultiplier_OID_S )
		SetSliderDialogStartValue(NW_TreeSpiritMultiplier)
		SetSliderDialogDefaultValue(8)
		SetSliderDialogRange(6, 15)
		SetSliderDialogInterval(1)
		Return
	EndIf
EndEvent

Event OnOptionSliderAccept(int option, float value)
	If ( option == NW_StatMultiplier_OID_S )
		NW_StatMultiplier = value
		SetSliderOptionValue(NW_StatMultiplier_OID_S, NW_StatMultiplier, "{2}")
		Return
	EndIf
	If ( option == NW_TreeSpiritMultiplier_OID_S )
		NW_TreeSpiritMultiplier = value
		SetSliderOptionValue(NW_TreeSpiritMultiplier_OID_S, NW_TreeSpiritMultiplier, "{0}")
		Return
	EndIf
EndEvent

Event OnOptionDefault(int option)
	{Called when resetting an option to its default value}

	If ( option == NW_IntroAnimEnabled_OID_B )
		NW_IntroAnimEnabled = true
		SetToggleOptionValue(NW_IntroAnimEnabled_OID_B, NW_IntroAnimEnabled)
		Return
	EndIf

	If ( option == NW_OutroAnimEnabled_OID_B )
		NW_OutroAnimEnabled = true
		SetToggleOptionValue(NW_OutroAnimEnabled_OID_B, NW_OutroAnimEnabled)
		Return
	EndIf

	If ( option == NW_AmbientEffectEnabled_OID_B )
		NW_AmbientEffectEnabled = true
		SetToggleOptionValue(NW_AmbientEffectEnabled_OID_B, NW_AmbientEffectEnabled)
		Return
	EndIf

	If ( option == NW_CloakEffectEnabled_OID_B )
		NW_CloakEffectEnabled = true
		SetToggleOptionValue(NW_CloakEffectEnabled_OID_B, NW_CloakEffectEnabled)
		Return
	EndIf

	If ( option == NW_StatMultiplier_OID_S )
		NW_StatMultiplier = 1.0
		SetSliderOptionValue(NW_StatMultiplier_OID_S, NW_StatMultiplier, "{2}")
		Return
	EndIf
	If ( option == NW_TreeSpiritMultiplier_OID_S )
		NW_TreeSpiritMultiplier = 8
		SetSliderOptionValue(NW_TreeSpiritMultiplier_OID_S, NW_TreeSpiritMultiplier, "{0}")
		Return
	EndIf
EndEvent
